.. currentmodule:: abjad.tools.pitchtools

transpose_named_pitch_by_numbered_interval_and_respell
======================================================

.. autofunction:: transpose_named_pitch_by_numbered_interval_and_respell
